@@ -12,7 +12,7 @@ use Ref::Util qw( is_blessed_ref );
 use Carp ();
 
 # ABSTRACT: Wasmtime linker class
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 
 $ffi_prefix = 'wasmtime_linker_';
@@ -34,151 +34,70 @@ $ffi->attach( allow_shadowing => [ 'wasmtime_linker_t', 'bool' ] => sub {
 });
 
 
-if(Wasm::Wasmtime::Error->can('new'))
-{
-  $ffi->attach( define => ['wasmtime_linker_t', 'wasm_byte_vec_t*', 'wasm_byte_vec_t*', 'opaque'] => 'wasmtime_error_t' => sub {
-    my $xsub   = shift;
-    my $self   = shift;
-    my $module = Wasm::Wasmtime::ByteVec->new(shift);
-    my $name   = Wasm::Wasmtime::ByteVec->new(shift);
-    my $extern = shift;
+$ffi->attach( define => ['wasmtime_linker_t', 'wasm_byte_vec_t*', 'wasm_byte_vec_t*', 'opaque'] => 'wasmtime_error_t' => sub {
+  my $xsub   = shift;
+  my $self   = shift;
+  my $module = Wasm::Wasmtime::ByteVec->new(shift);
+  my $name   = Wasm::Wasmtime::ByteVec->new(shift);
+  my $extern = shift;
 
-    # Fix this sillyness when/if ::Extern becomes a base class for extern classes
-    if(is_blessed_ref($extern) && (   $extern->isa('Wasm::Wasmtime::Extern')
-                                   || $extern->isa('Wasm::Wasmtime::Func')
-                                   || $extern->isa('Wasm::Wasmtime::Memory')
-                                   || $extern->isa('Wasm::Wasmtime::Global')
-                                   || $extern->isa('Wasm::Wasmtime::Table')))
-    {
-      my $error = $xsub->($self, $module, $name, $extern->{ptr});
-      Carp::croak($error->message) if $error;
-      return $self;
-    }
-    else
-    {
-      Carp::croak("not an extern: $extern");
-    }
-  });
-}
-else
-{
-  $ffi->attach( define => ['wasmtime_linker_t', 'wasm_byte_vec_t*', 'wasm_byte_vec_t*', 'opaque'] => 'bool' => sub {
-    my $xsub   = shift;
-    my $self   = shift;
-    my $module = Wasm::Wasmtime::ByteVec->new(shift);
-    my $name   = Wasm::Wasmtime::ByteVec->new(shift);
-    my $extern = shift;
-
-    # Fix this sillyness when/if ::Extern becomes a base class for extern classes
-    if(is_blessed_ref($extern) && (   $extern->isa('Wasm::Wasmtime::Extern')
-                                   || $extern->isa('Wasm::Wasmtime::Func')
-                                   || $extern->isa('Wasm::Wasmtime::Memory')
-                                   || $extern->isa('Wasm::Wasmtime::Global')
-                                   || $extern->isa('Wasm::Wasmtime::Table')))
-    {
-      my $ret = $xsub->($self, $module, $name, $extern->{ptr});
-      Carp::croak("Unknown error in define") unless $ret;
-      return $self;
-    }
-    else
-    {
-      Carp::croak("not an extern: $extern");
-    }
-
-  });
-}
-
-
-if(Wasm::Wasmtime::Error->can('new'))
-{
-  $ffi->attach( define_wasi => ['wasmtime_linker_t', 'wasi_instance_t'] => 'wasmtime_error_t' => sub {
-    my($xsub, $self, $wasi) = @_;
-    my $error = $xsub->($self, $wasi);
+  # Fix this sillyness when/if ::Extern becomes a base class for extern classes
+  if(is_blessed_ref($extern) && (   $extern->isa('Wasm::Wasmtime::Extern')
+                                 || $extern->isa('Wasm::Wasmtime::Func')
+                                 || $extern->isa('Wasm::Wasmtime::Memory')
+                                 || $extern->isa('Wasm::Wasmtime::Global')
+                                 || $extern->isa('Wasm::Wasmtime::Table')))
+  {
+    my $error = $xsub->($self, $module, $name, $extern->{ptr});
     Carp::croak($error->message) if $error;
-    $self;
-  });
-}
-else
-{
-  $ffi->attach( define_wasi => ['wasmtime_linker_t', 'wasi_instance_t'] => 'bool' => sub {
-    my($xsub, $self, $wasi) = @_;
-    my $ret = $xsub->($self, $wasi);
-    Carp::croak("Unknown error in define_wasi") unless $ret;
-    $self;
-  });
-}
+    return $self;
+  }
+  else
+  {
+    Carp::croak("not an extern: $extern");
+  }
+});
 
 
-if(Wasm::Wasmtime::Error->can('new'))
-{
-  $ffi->attach( define_instance => ['wasmtime_linker_t', 'wasm_byte_vec_t*', 'wasm_instance_t'] => 'wasmtime_error_t' => sub {
-    my($xsub, $self, $name, $instance) = @_;
-    my $vname = Wasm::Wasmtime::ByteVec->new($name);
-    my $error = $xsub->($self, $vname, $instance);
-    Carp::croak($error->message) if $error;
-    $self;
-  });
-}
-else
-{
-  $ffi->attach( define_instance => ['wasmtime_linker_t', 'wasm_byte_vec_t*', 'wasm_instance_t'] => 'bool' => sub {
-    my($xsub, $self, $name, $instance) = @_;
-    my $vname = Wasm::Wasmtime::ByteVec->new($name);
-    my $ret = $xsub->($self, $vname, $instance);
-    Carp::croak("Unknown error in define_instance") unless $ret;
-    $self;
-  });
-}
+$ffi->attach( define_wasi => ['wasmtime_linker_t', 'wasi_instance_t'] => 'wasmtime_error_t' => sub {
+  my($xsub, $self, $wasi) = @_;
+  my $error = $xsub->($self, $wasi);
+  Carp::croak($error->message) if $error;
+  $self;
+});
 
 
-if(Wasm::Wasmtime::Error->can('new'))
-{
-  $ffi->attach( instantiate => ['wasmtime_linker_t','wasm_module_t','opaque*','opaque*'] => 'wasmtime_error_t' => sub {
-    my($xsub, $self, $module) = @_;
-    my $trap;
-    my $ptr;
-    my $error = $xsub->($self, $module, \$ptr, \$trap);
-    Carp::croak($error->message) if $error;
-    if($trap)
-    {
-      $trap = Wasm::Wasmtime::Trap->new($trap);
-      Carp::croak($trap->message);
-    }
-    elsif($ptr)
-    {
-      return Wasm::Wasmtime::Instance->new(
-        $module, $ptr,
-      );
-    }
-    else
-    {
-      Carp::croak("unknown instantiate error");
-    }
-  });
-}
-else
-{
-  $ffi->attach( instantiate => ['wasmtime_linker_t','wasm_module_t','opaque*' ] => 'opaque' => sub {
-    my($xsub, $self, $module) = @_;
-    my $trap;
-    my $ptr = $xsub->($self, $module, \$trap);
-    if($trap)
-    {
-      $trap = Wasm::Wasmtime::Trap->new($trap);
-      Carp::croak($trap->message);
-    }
-    elsif($ptr)
-    {
-      return Wasm::Wasmtime::Instance->new(
-        $module, $ptr,
-      );
-    }
-    else
-    {
-      Carp::croak("unknown instantiate error");
-    }
-  });
-}
+$ffi->attach( define_instance => ['wasmtime_linker_t', 'wasm_byte_vec_t*', 'wasm_instance_t'] => 'wasmtime_error_t' => sub {
+  my($xsub, $self, $name, $instance) = @_;
+  my $vname = Wasm::Wasmtime::ByteVec->new($name);
+  my $error = $xsub->($self, $vname, $instance);
+  Carp::croak($error->message) if $error;
+  $self;
+});
+
+
+$ffi->attach( instantiate => ['wasmtime_linker_t','wasm_module_t','opaque*','opaque*'] => 'wasmtime_error_t' => sub {
+  my($xsub, $self, $module) = @_;
+  my $trap;
+  my $ptr;
+  my $error = $xsub->($self, $module, \$ptr, \$trap);
+  Carp::croak($error->message) if $error;
+  if($trap)
+  {
+    $trap = Wasm::Wasmtime::Trap->new($trap);
+    Carp::croak($trap->message);
+  }
+  elsif($ptr)
+  {
+    return Wasm::Wasmtime::Instance->new(
+      $module, $ptr,
+    );
+  }
+  else
+  {
+    Carp::croak("unknown instantiate error");
+  }
+});
 
 
 sub store { shift->{store} }
@@ -199,7 +118,7 @@ Wasm::Wasmtime::Linker - Wasmtime linker class
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
