@@ -6,7 +6,7 @@ use Wasm::Wasmtime::FFI;
 use base qw( Exporter );
 
 # ABSTRACT: Convert WebAssembly Text to Wasm
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 
 our @EXPORT = qw( wat2wasm );
@@ -14,46 +14,22 @@ our @EXPORT = qw( wat2wasm );
 $ffi_prefix = 'wasmtime_';
 
 
-if(Wasm::Wasmtime::Error->can('new'))
-{
-  $ffi->attach( wat2wasm => ['wasm_byte_vec_t*','wasm_byte_vec_t*'] => 'wasmtime_error_t' => sub {
-    my $xsub = shift;
-    my $wat = Wasm::Wasmtime::ByteVec->new($_[0]);
-    my $ret = Wasm::Wasmtime::ByteVec->new;
-    my $error = $xsub->($wat, $ret);
-    if($error)
-    {
-      Carp::croak($error->message . "\nwat2wasm error");
-    }
-    else
-    {
-      my $wasm = $ret->get;
-      $ret->delete;
-      return $wasm;
-    }
-  });
-}
-else
-{
-  $ffi->attach( wat2wasm => ['wasm_byte_vec_t*','wasm_byte_vec_t*','wasm_byte_vec_t*'] => 'bool' => sub {
-    my $xsub = shift;
-    my $wat = Wasm::Wasmtime::ByteVec->new($_[0]);
-    my $ret = Wasm::Wasmtime::ByteVec->new;
-    my $error_message = Wasm::Wasmtime::ByteVec->new;
-    if($xsub->($wat, $ret, $error_message))
-    {
-      my $wasm = $ret->get;
-      $ret->delete;
-      return $wasm;
-    }
-    else
-    {
-      my $diag = $error_message->get;
-      $error_message->delete;
-      Carp::croak($diag . "\nwat2wasm error");
-    }
-  });
-}
+$ffi->attach( wat2wasm => ['wasm_byte_vec_t*','wasm_byte_vec_t*'] => 'wasmtime_error_t' => sub {
+  my $xsub = shift;
+  my $wat = Wasm::Wasmtime::ByteVec->new($_[0]);
+  my $ret = Wasm::Wasmtime::ByteVec->new;
+  my $error = $xsub->($wat, $ret);
+  if($error)
+  {
+    Carp::croak($error->message . "\nwat2wasm error");
+  }
+  else
+  {
+    my $wasm = $ret->get;
+    $ret->delete;
+    return $wasm;
+  }
+});
 
 1;
 
@@ -69,7 +45,7 @@ Wasm::Wasmtime::Wat2Wasm - Convert WebAssembly Text to Wasm
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
